@@ -1,10 +1,10 @@
+# -*- coding: utf-8 -*-
 """
 Django Extensions additional model fields
 """
 import re
 import six
 import string
-import warnings
 
 try:
     import uuid
@@ -18,25 +18,16 @@ try:
 except ImportError:
     HAS_SHORT_UUID = False
 
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import DateTimeField, CharField, SlugField
-from django.utils.crypto import get_random_string
+from django.db.models.constants import LOOKUP_SEP
 from django.template.defaultfilters import slugify
-
-try:
-    from django.utils.timezone import now as datetime_now
-    assert datetime_now
-except ImportError:
-    import datetime
-    datetime_now = datetime.datetime.now
-
-try:
-    from django.utils.encoding import force_unicode  # NOQA
-except ImportError:
-    from django.utils.encoding import force_text as force_unicode  # NOQA
+from django.utils.crypto import get_random_string
+from django.utils.encoding import force_text
 
 
-MAX_UNIQUE_QUERY_ATTEMPTS = 100
+MAX_UNIQUE_QUERY_ATTEMPTS = getattr(settings, 'EXTENSIONS_MAX_UNIQUE_QUERY_ATTEMPTS', 100)
 
 
 class UniqueFieldMixin(object):
@@ -45,8 +36,15 @@ class UniqueFieldMixin(object):
         if not isinstance(getattr(self, attrname), bool):
             raise ValueError("'{}' argument must be True or False".format(attrname))
 
+    @staticmethod
+    def _get_fields(model_cls):
+        return [
+            (f, f.model if f.model != model_cls else None) for f in model_cls._meta.get_fields()
+            if not f.is_relation or f.one_to_one or (f.many_to_one and f.related_model)
+        ]
+
     def get_queryset(self, model_cls, slug_field):
-        for field, model in model_cls._meta.get_fields_with_model():
+        for field, model in self._get_fields(model_cls):
             if model and field == slug_field:
                 return model._default_manager.all()
         return model_cls._default_manager.all()
@@ -82,7 +80,12 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
     Required arguments:
 
     populate_from
-        Specifies which field or list of fields the slug is populated from.
+        Specifies which field, list of fields, or model method
+        the slug will be populated from.
+
+        populate_from can traverse a ForeignKey relationship
+        by using Django ORM syntax:
+            populate_from = 'related_model__field'
 
     Optional arguments:
 
@@ -111,6 +114,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         self.check_is_bool('overwrite')
         self.allow_duplicates = kwargs.pop('allow_duplicates', False)
         self.check_is_bool('allow_duplicates')
+        self.max_unique_query_attempts = kwargs.pop('max_unique_query_attempts', MAX_UNIQUE_QUERY_ATTEMPTS)
         super(AutoSlugField, self).__init__(*args, **kwargs)
 
     def _slug_strip(self, value):
@@ -132,7 +136,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
 
     def slug_generator(self, original_slug, start):
         yield original_slug
-        for i in range(start, MAX_UNIQUE_QUERY_ATTEMPTS):
+        for i in range(start, self.max_unique_query_attempts):
             slug = original_slug
             end = '%s%s' % (self.separator, i)
             end_len = len(end)
@@ -141,8 +145,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
                 slug = self._slug_strip(slug)
             slug = '%s%s' % (slug, end)
             yield slug
-        raise RuntimeError('max slug attempts for %s exceeded (%s)' %
-            (original_slug, MAX_UNIQUE_QUERY_ATTEMPTS))
+        raise RuntimeError('max slug attempts for %s exceeded (%s)' % (original_slug, self.max_unique_query_attempts))
 
     def create_slug(self, model_instance, add):
         # get fields to populate from and slug field to set
@@ -152,7 +155,7 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
 
         if add or self.overwrite:
             # slugify the original field content and set next step to 2
-            slug_for_field = lambda field: self.slugify_func(getattr(model_instance, field))
+            slug_for_field = lambda lookup_value: self.slugify_func(self.get_slug_fields(model_instance, lookup_value))
             slug = self.separator.join(map(slug_for_field, self._populate_from))
             start = 2
         else:
@@ -171,33 +174,35 @@ class AutoSlugField(UniqueFieldMixin, SlugField):
         original_slug = slug
 
         if self.allow_duplicates:
+            setattr(model_instance, self.attname, slug)
             return slug
 
         return super(AutoSlugField, self).find_unique(
             model_instance, slug_field, self.slug_generator(original_slug, start))
 
+    def get_slug_fields(self, model_instance, lookup_value):
+        lookup_value_path = lookup_value.split(LOOKUP_SEP)
+        attr = model_instance
+        for elem in lookup_value_path:
+            try:
+                attr = getattr(attr, elem)
+            except AttributeError:
+                raise AttributeError(
+                    "value {} in AutoSlugField's 'populate_from' argument {} returned an error - {} has no attribute {}".format(
+                        elem, lookup_value, attr, elem))
+
+        if callable(attr):
+            return "%s" % attr()
+
+        return attr
+
     def pre_save(self, model_instance, add):
-        value = force_unicode(self.create_slug(model_instance, add))
+        value = force_text(self.create_slug(model_instance, add))
         return value
 
     def get_internal_type(self):
         return "SlugField"
 
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
-        # We'll just introspect the _actual_ field.
-        from south.modelsinspector import introspector
-        field_class = '%s.AutoSlugField' % self.__module__
-        args, kwargs = introspector(self)
-        kwargs.update({
-            'populate_from': repr(self._populate_from),
-            'separator': repr(self.separator),
-            'overwrite': repr(self.overwrite),
-            'allow_duplicates': repr(self.allow_duplicates),
-        })
-        # That's our definition!
-        return (field_class, args, kwargs)
-
     def deconstruct(self):
         name, path, args, kwargs = super(AutoSlugField, self).deconstruct()
         kwargs['populate_from'] = self._populate_from
@@ -261,6 +266,7 @@ class RandomCharField(UniqueFieldMixin, CharField):
         self.check_is_bool('include_alpha')
         self.include_punctuation = kwargs.pop('include_punctuation', False)
         self.check_is_bool('include_punctuation')
+        self.max_unique_query_attempts = kwargs.pop('max_unique_query_attempts', MAX_UNIQUE_QUERY_ATTEMPTS)
 
         # Set unique=False unless it's been set manually.
         if 'unique' not in kwargs:
@@ -269,10 +275,9 @@ class RandomCharField(UniqueFieldMixin, CharField):
         super(RandomCharField, self).__init__(*args, **kwargs)
 
     def random_char_generator(self, chars):
-        for i in range(MAX_UNIQUE_QUERY_ATTEMPTS):
+        for i in range(self.max_unique_query_attempts):
             yield ''.join(get_random_string(self.length, chars))
-        raise RuntimeError('max random character attempts exceeded (%s)' %
-            MAX_UNIQUE_QUERY_ATTEMPTS)
+        raise RuntimeError('max random character attempts exceeded (%s)' % self.max_unique_query_attempts)
 
     def pre_save(self, model_instance, add):
         if not add and getattr(model_instance, self.attname) != '':
@@ -295,7 +300,9 @@ class RandomCharField(UniqueFieldMixin, CharField):
 
         random_chars = self.random_char_generator(population)
         if not self.unique:
-            return random_chars
+            new = six.next(random_chars)
+            setattr(model_instance, self.attname, new)
+            return new
 
         return super(RandomCharField, self).find_unique(
             model_instance,
@@ -306,24 +313,6 @@ class RandomCharField(UniqueFieldMixin, CharField):
     def internal_type(self):
         return "CharField"
 
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
-        # We'll just introspect the _actual_ field.
-        from south.modelsinspector import introspector
-        field_class = '%s.RandomCharField' % self.__module__
-        args, kwargs = introspector(self)
-        kwargs.update({
-            'lowercase': repr(self.lowercase),
-            'include_digits': repr(self.include_digits),
-            'include_aphla': repr(self.include_alpha),
-            'include_punctuation': repr(self.include_punctuation),
-            'length': repr(self.length),
-            'unique': repr(self.unique),
-        })
-        del kwargs['max_length']
-        # That's our definition!
-        return (field_class, args, kwargs)
-
     def deconstruct(self):
         name, path, args, kwargs = super(RandomCharField, self).deconstruct()
         kwargs['length'] = self.length
@@ -358,14 +347,6 @@ class CreationDateTimeField(DateTimeField):
     def get_internal_type(self):
         return "DateTimeField"
 
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
-        # We'll just introspect ourselves, since we inherit.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.DateTimeField"
-        args, kwargs = introspector(self)
-        return (field_class, args, kwargs)
-
     def deconstruct(self):
         name, path, args, kwargs = super(CreationDateTimeField, self).deconstruct()
         if self.editable is not False:
@@ -392,27 +373,24 @@ class ModificationDateTimeField(CreationDateTimeField):
     def get_internal_type(self):
         return "DateTimeField"
 
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
-        # We'll just introspect ourselves, since we inherit.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.DateTimeField"
-        args, kwargs = introspector(self)
-        return (field_class, args, kwargs)
-
     def deconstruct(self):
         name, path, args, kwargs = super(ModificationDateTimeField, self).deconstruct()
         if self.auto_now is not False:
             kwargs['auto_now'] = True
         return name, path, args, kwargs
 
+    def pre_save(self, model_instance, add):
+        if not getattr(model_instance, 'update_modified', True):
+            return model_instance.modified
+        return super(ModificationDateTimeField, self).pre_save(model_instance, add)
+
 
 class UUIDVersionError(Exception):
     pass
 
 
-class UUIDField(CharField):
-    """ UUIDField
+class UUIDFieldMixin(object):
+    """ UUIDFieldMixin
 
     By default uses UUID version 4 (randomly generated UUID).
 
@@ -421,23 +399,29 @@ class UUIDField(CharField):
     """
     DEFAULT_MAX_LENGTH = 36
 
-    def __init__(self, verbose_name=None, name=None, auto=True, version=4, node=None, clock_seq=None, namespace=None, uuid_name=None, *args, **kwargs):
-        warnings.warn("Django 1.8 features a native UUIDField, this UUIDField will be removed after Django 1.7 becomes unsupported.", DeprecationWarning)
-
+    def __init__(
+            self, verbose_name=None, name=None, auto=True, version=4,
+            node=None, clock_seq=None, namespace=None, uuid_name=None, *args,
+            **kwargs):
         if not HAS_UUID:
             raise ImproperlyConfigured("'uuid' module is required for UUIDField. (Do you have Python 2.5 or higher installed ?)")
+
         kwargs.setdefault('max_length', self.DEFAULT_MAX_LENGTH)
+
         if auto:
             self.empty_strings_allowed = False
             kwargs['blank'] = True
             kwargs.setdefault('editable', False)
+
         self.auto = auto
         self.version = version
         self.node = node
         self.clock_seq = clock_seq
         self.namespace = namespace
         self.uuid_name = uuid_name or name
-        super(UUIDField, self).__init__(verbose_name=verbose_name, *args, **kwargs)
+
+        super(UUIDFieldMixin, self).__init__(
+            verbose_name=verbose_name, *args, **kwargs)
 
     def create_uuid(self):
         if not self.version or self.version == 4:
@@ -454,33 +438,27 @@ class UUIDField(CharField):
             raise UUIDVersionError("UUID version %s is not valid." % self.version)
 
     def pre_save(self, model_instance, add):
-        value = super(UUIDField, self).pre_save(model_instance, add)
+        value = super(UUIDFieldMixin, self).pre_save(model_instance, add)
+
         if self.auto and add and value is None:
-            value = force_unicode(self.create_uuid())
+            value = force_text(self.create_uuid())
             setattr(model_instance, self.attname, value)
             return value
         else:
             if self.auto and not value:
-                value = force_unicode(self.create_uuid())
+                value = force_text(self.create_uuid())
                 setattr(model_instance, self.attname, value)
+
         return value
 
     def formfield(self, **kwargs):
         if self.auto:
             return None
-        return super(UUIDField, self).formfield(**kwargs)
-
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
-        # We'll just introspect the _actual_ field.
-        from south.modelsinspector import introspector
-        field_class = "django.db.models.fields.CharField"
-        args, kwargs = introspector(self)
-        # That's our definition!
-        return (field_class, args, kwargs)
+        return super(UUIDFieldMixin, self).formfield(**kwargs)
 
     def deconstruct(self):
-        name, path, args, kwargs = super(UUIDField, self).deconstruct()
+        name, path, args, kwargs = super(UUIDFieldMixin, self).deconstruct()
+
         if kwargs.get('max_length', None) == self.DEFAULT_MAX_LENGTH:
             del kwargs['max_length']
         if self.auto is not True:
@@ -495,30 +473,11 @@ class UUIDField(CharField):
             kwargs['namespace'] = self.namespace
         if self.uuid_name is not None:
             kwargs['uuid_name'] = self.name
+
         return name, path, args, kwargs
 
 
-class PostgreSQLUUIDField(UUIDField):
-    def __init__(self, *args, **kwargs):
-        warnings.warn("Django 1.8 features a native UUIDField, this UUIDField will be removed after Django 1.7 becomes unsupported.", DeprecationWarning)
-        super(PostgreSQLUUIDField, self).__init__(*args, **kwargs)
-
-    def db_type(self, connection=None):
-        return "UUID"
-
-    def get_db_prep_value(self, value, connection, prepared=False):
-        if isinstance(value, six.integer_types):
-            value = uuid.UUID(int=value)
-        elif isinstance(value, (six.string_types, six.binary_type)):
-            if len(value) == 16:
-                value = uuid.UUID(bytes=value)
-            else:
-                value = uuid.UUID(value)
-        return super(PostgreSQLUUIDField, self).get_db_prep_value(
-            value, connection, prepared=False)
-
-
-class ShortUUIDField(UUIDField):
+class ShortUUIDField(UUIDFieldMixin, CharField):
     """ ShortUUIDFied
 
     Generates concise (22 characters instead of 36), unambiguous, URL-safe UUIDs.
