@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 """
 Sets up the terminal color scheme.
 """
@@ -11,9 +11,16 @@ def _dummy_style_func(msg):
     return msg
 
 
+def no_style():
+    style = color.no_style()
+    for role in ('INFO', 'WARN', 'BOLD', 'URL', 'MODULE', 'MODULE_NAME', 'URL_NAME'):
+        setattr(style, role, _dummy_style_func)
+    return style
+
+
 def color_style():
-    style = color.color_style()
     if color.supports_color():
+        style = color.color_style()
         style.INFO = termcolors.make_style(fg='green')
         style.WARN = termcolors.make_style(fg='yellow')
         style.BOLD = termcolors.make_style(opts=('bold',))
@@ -22,7 +29,5 @@ def color_style():
         style.MODULE_NAME = termcolors.make_style(opts=('bold',))
         style.URL_NAME = termcolors.make_style(fg='red')
     else:
-        for role in ('INFO', 'WARN', 'BOLD', 'URL', 'MODULE', 'MODULE_NAME', 'URL_NAME'):
-            if not hasattr(style, role):
-                setattr(style, role, _dummy_style_func)
+        style = no_style()
     return style
