@@ -1,4 +1,4 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 """
 set_fake_emails.py
 
@@ -9,10 +9,10 @@ set_fake_emails.py
 """
 
 from django.conf import settings
-from django.core.management.base import CommandError
+from django.contrib.auth import get_user_model
+from django.core.management.base import BaseCommand, CommandError
 
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
 DEFAULT_FAKE_EMAIL = '%(username)s@example.com'
 
@@ -22,6 +22,7 @@ class Command(BaseCommand):
     requires_system_checks = False
 
     def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
         parser.add_argument(
             '--email', dest='default_email', default=DEFAULT_FAKE_EMAIL,
             help='Use this as the new email format.')
@@ -49,7 +50,6 @@ class Command(BaseCommand):
         if not settings.DEBUG:
             raise CommandError('Only available in debug mode')
 
-        from django_extensions.compat import get_user_model
         from django.contrib.auth.models import Group
         email = options.get('default_email', DEFAULT_FAKE_EMAIL)
         include_regexp = options.get('include_regexp', None)
