@@ -49,7 +49,7 @@ class Command(BaseCommand):
             '--kernel', action='store_true', dest='kernel',
             help='Tells Django to start an IPython Kernel.')
         parser.add_argument('--connection-file', action='store', dest='connection_file',
-                    help='Specifies the connection file to use if using the --kernel option'),
+            help='Specifies the connection file to use if using the --kernel option'),
         parser.add_argument(
             '--use-pythonrc', action='store_true', dest='use_pythonrc',
             help='Tells Django to execute PYTHONSTARTUP file '
@@ -76,7 +76,14 @@ class Command(BaseCommand):
         return getattr(settings, 'IPYTHON_ARGUMENTS', [])
 
     def get_notebook_arguments(self, options):
-        return getattr(settings, 'NOTEBOOK_ARGUMENTS', [])
+        notebook_args = 'NOTEBOOK_ARGUMENTS'
+        arguments = getattr(settings, notebook_args, [])
+        if not arguments:
+            arguments = os.environ.get(notebook_args, '').split()
+        return arguments
+
+    def get_imported_objects(self, options):
+        return import_objects(options, self.style)
 
     @signalcommand
     def handle(self, *args, **options):
@@ -91,15 +98,21 @@ class Command(BaseCommand):
         no_browser = options.get('no_browser', False)
         verbosity = int(options.get('verbosity', 1))
         print_sql = getattr(settings, 'SHELL_PLUS_PRINT_SQL', False)
+        truncate = getattr(settings, 'SHELL_PLUS_PRINT_SQL_TRUNCATE', 1000)
 
         if options.get("print_sql", False) or print_sql:
 
             # Code from http://gist.github.com/118990
-            sqlparse = None
             try:
                 import sqlparse
             except ImportError:
-                pass
+                sqlparse = None
+
+            try:
+                import pygments.lexers
+                import pygments.formatters
+            except ImportError:
+                pygments = None
 
             class PrintQueryWrapper(utils.CursorDebugWrapper):
                 def execute(self, sql, params=()):
@@ -109,10 +122,19 @@ class Command(BaseCommand):
                     finally:
                         execution_time = time.time() - starttime
                         raw_sql = self.db.ops.last_executed_query(self.cursor, sql, params)
+
                         if sqlparse:
-                            print(sqlparse.format(raw_sql, reindent=True))
-                        else:
-                            print(raw_sql)
+                            raw_sql = raw_sql[:truncate]
+                            raw_sql = sqlparse.format(raw_sql, reindent_aligned=True, truncate_strings=500)
+
+                        if pygments:
+                            raw_sql = pygments.highlight(
+                                raw_sql,
+                                pygments.lexers.get_lexer_by_name("sql"),
+                                pygments.formatters.TerminalFormatter()
+                            )
+
+                        print(raw_sql)
                         print("")
                         print('Execution time: %.6fs [Database: %s]' % (execution_time, self.db.alias))
                         print("")
@@ -130,7 +152,7 @@ class Command(BaseCommand):
                 return traceback.format_exc()
 
             def run_kernel():
-                imported_objects = import_objects(options, self.style)
+                imported_objects = self.get_imported_objects(options)
                 kwargs = dict(
                     argv=[],
                     user_ns=imported_objects,
@@ -226,7 +248,7 @@ class Command(BaseCommand):
         def get_plain():
             # Using normal Python shell
             import code
-            imported_objects = import_objects(options, self.style)
+            imported_objects = self.get_imported_objects(options)
             try:
                 # Try activating rlcompleter, because it's handy.
                 import readline
@@ -268,7 +290,7 @@ class Command(BaseCommand):
                 return traceback.format_exc()
 
             def run_bpython():
-                imported_objects = import_objects(options, self.style)
+                imported_objects = self.get_imported_objects(options)
                 embed(imported_objects)
             return run_bpython
 
@@ -277,7 +299,7 @@ class Command(BaseCommand):
                 from IPython import start_ipython
 
                 def run_ipython():
-                    imported_objects = import_objects(options, self.style)
+                    imported_objects = self.get_imported_objects(options)
                     ipython_arguments = self.get_ipython_arguments(options)
                     start_ipython(argv=ipython_arguments, user_ns=imported_objects)
                 return run_ipython
@@ -293,7 +315,7 @@ class Command(BaseCommand):
                     return str_exc + "\n" + traceback.format_exc()
 
                 def run_ipython():
-                    imported_objects = import_objects(options, self.style)
+                    imported_objects = self.get_imported_objects(options)
                     shell = IPShell(argv=[], user_ns=imported_objects)
                     shell.mainloop()
                 return run_ipython
@@ -309,7 +331,7 @@ class Command(BaseCommand):
                     return tb
 
             def run_ptpython():
-                imported_objects = import_objects(options, self.style)
+                imported_objects = self.get_imported_objects(options)
                 history_filename = os.path.expanduser('~/.ptpython_history')
                 embed(globals=imported_objects, history_filename=history_filename,
                       vi_mode=options.get('vi_mode', False), configure=run_config)
@@ -328,7 +350,7 @@ class Command(BaseCommand):
                     return tb
 
             def run_ptipython():
-                imported_objects = import_objects(options, self.style)
+                imported_objects = self.get_imported_objects(options)
                 history_filename = os.path.expanduser('~/.ptpython_history')
                 embed(user_ns=imported_objects, history_filename=history_filename,
                       vi_mode=options.get('vi_mode', False), configure=run_config)
@@ -342,7 +364,8 @@ class Command(BaseCommand):
 
             http://www.postgresql.org/docs/9.4/static/libpq-connect.html#LIBPQ-PARAMKEYWORDS  # noqa
             """
-            supported_backends = ['django.db.backends.postgresql_psycopg2']
+            supported_backends = ['django.db.backends.postgresql',
+                                  'django.db.backends.postgresql_psycopg2']
             opt_name = 'fallback_application_name'
             default_app_name = 'django_shell'
             app_name = default_app_name
