@@ -1,12 +1,11 @@
-# coding=utf-8
+# -*- coding: utf-8 -*-
 import socket
 import sys
 
 from django.conf import settings
-from django.core.management.base import CommandError
+from django.core.management.base import BaseCommand, CommandError
 
 from django_extensions.management.utils import signalcommand
-from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
 
 class Command(BaseCommand):
@@ -20,6 +19,7 @@ The envisioned use case is something like this:
     can_import_settings = True
 
     def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
         parser.add_argument(
             '-R', '--router', action='store', dest='router', default='default',
             help='Use this router-database other then defined in settings.py')
@@ -56,7 +56,7 @@ The envisioned use case is something like this:
                 dbname, dbuser, dbclient, dbpass
             ))
 
-        elif engine == 'postgresql_psycopg2':
+        elif engine in ('postgresql', 'postgresql_psycopg2'):
             if options.get('drop'):
                 print("DROP DATABASE IF EXISTS %s;" % (dbname,))
                 print("DROP USER IF EXISTS %s;" % (dbuser,))
