@@ -449,6 +449,9 @@ class SQLDiff(object):
             table_name = meta.db_table
             app_label = meta.app_label
 
+            if self.options.get('include_proxy_models', False) and meta.proxy:
+                continue
+
             if cur_app_label != app_label:
                 # Marker indicating start of difference scan for this table_name
                 self.add_app_model_marker(app_label, app_model.__name__)
@@ -635,7 +638,7 @@ class MySQLDiff(SQLDiff):
                 db_type = db_type.lstrip("var")
             # They like to call 'bool's 'tinyint(1)' and introspection makes that a integer
             # just convert it back to it's proper type, a bool is a bool and nothing else.
-            if db_type == 'integer' and description[1] == FIELD_TYPE.TINY and description[4] == 1:
+            if db_type == 'integer' and description[1] == FIELD_TYPE.TINY and description[2] == 1:
                 db_type = 'bool'
             if (table_name, field.column) in self.auto_increment:
                 db_type += ' AUTO_INCREMENT'
@@ -651,7 +654,7 @@ class SqliteSQLDiff(SQLDiff):
             tablespace = "public"
             # index, column_name, column_type, nullable, default_value
             # see: http://www.sqlite.org/pragma.html#pragma_table_info
-            for table_info in self.sql_to_dict("PRAGMA table_info(%s);" % table_name, []):
+            for table_info in self.sql_to_dict("PRAGMA table_info('%s');" % table_name, []):
                 key = (tablespace, table_name, table_info['name'])
                 self.null[key] = not table_info['notnull']
 
@@ -874,6 +877,7 @@ class PostgresqlSQLDiff(SQLDiff):
         super(PostgresqlSQLDiff, self).find_field_type_differ(meta, table_description, table_name, callback)
     """
 
+
 DATABASE_SQLDIFF_CLASSES = {
     'postgis': PostgresqlSQLDiff,
     'postgresql_psycopg2': PostgresqlSQLDiff,
@@ -914,6 +918,10 @@ to check/debug ur models compared to the real database tables and columns."""
             '--output_text', '-t', action='store_false', dest='sql',
             default=True,
             help="Outputs the differences as descriptive text instead of SQL")
+        parser.add_argument(
+            '--include-proxy-models', action='store_true', dest='include_proxy_models',
+            default=False,
+            help="Include proxy models in the graph")
 
     def __init__(self, *args, **kwargs):
         super(Command, self).__init__(*args, **kwargs)
