@@ -1,14 +1,18 @@
 # -*- coding: utf-8 -*-
 import pytest
+import django
 from django.db import migrations, models
 from django.db.migrations.writer import MigrationWriter
 from django.test import TestCase
 from django.utils import six
+from django.utils.encoding import force_bytes
 
 import django_extensions  # noqa
 from django_extensions.db.fields import AutoSlugField
 
-from .testapp.models import ChildSluggedTestModel, SluggedTestModel
+from .testapp.models import ChildSluggedTestModel, SluggedTestModel, \
+    FKSluggedTestModel, FKSluggedTestModelCallable, \
+    ModelMethodSluggedTestModel
 
 
 @pytest.mark.usefixtures("admin_user")
@@ -89,6 +93,18 @@ class AutoSlugFieldTest(TestCase):
         n.save()
         self.assertEqual(n.slug, '-3')
 
+    def test_callable_slug_source(self):
+        m = ModelMethodSluggedTestModel(title='-foo')
+        m.save()
+        self.assertEqual(m.slug, 'the-title-is-foo')
+
+        n = ModelMethodSluggedTestModel(title='-foo')
+        n.save()
+        self.assertEqual(n.slug, 'the-title-is-foo-2')
+
+        n.save()
+        self.assertEqual(n.slug, 'the-title-is-foo-2')
+
     def test_inheritance_creates_next_slug(self):
         m = SluggedTestModel(title='foo')
         m.save()
@@ -101,12 +117,26 @@ class AutoSlugFieldTest(TestCase):
         o.save()
         self.assertEqual(o.slug, 'foo-3')
 
+    def test_foreign_key_populate_from_field(self):
+        m_fk = SluggedTestModel(title='foo')
+        m_fk.save()
+        m = FKSluggedTestModel(related_field=m_fk)
+        m.save()
+        self.assertEqual(m.slug, 'foo')
+
+    def test_foreign_key_populate_from_callable(self):
+        m_fk = ModelMethodSluggedTestModel(title='foo')
+        m_fk.save()
+        m = FKSluggedTestModelCallable(related_field=m_fk)
+        m.save()
+        self.assertEqual(m.slug, 'the-title-is-foo')
+
 
 class MigrationTest(TestCase):
     def safe_exec(self, string, value=None):
         l = {}
         try:
-            exec(string, globals(), l)
+            exec(force_bytes(string), globals(), l)
         except Exception as e:
             if value:
                 self.fail("Could not exec %r (from value %r): %s" % (string.strip(), value, e))
@@ -133,8 +163,13 @@ class MigrationTest(TestCase):
         writer = MigrationWriter(migration)
         output = writer.as_string()
         # It should NOT be unicode.
-        self.assertIsInstance(output, six.binary_type,
-                              "Migration as_string returned unicode")
+        if django.VERSION < (1, 11):
+            self.assertIsInstance(output, six.binary_type,
+                                "Migration as_string returned unicode")
+        else:
+            # As of Django 1.11 MigrationWriter.as_string returns unicode not bytes
+            self.assertIsInstance(output, six.text_type,
+                                "Migration as_string returned bytes")
         # We don't test the output formatting - that's too fragile.
         # Just make sure it runs for now, and that things look alright.
         result = self.safe_exec(output)
